/*
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDeveloper
 */

using System;
using NUnit.Framework;

namespace TopCoder.Rules.DependencyMap.View
{

    /// <summary>
    /// Unit test fixture for RendererException.
    /// </summary>
    [TestFixture]
    public class RendererExceptionUnitTests
    {

        /// <summary>
        /// The message to use.
        /// </summary>
        private string message = "renderer fails";

        /// <summary>
        /// The inner exception.
        /// </summary>
        private Exception cause = new Exception();

        /// <summary>
        /// Create instance with message.
        /// </summary>
        [Test]
        public void Create_Message()
        {
            RendererException re = new RendererException(message);
            Assert.AreEqual(message, re.Message, "Message mismatches.");
        }

        /// <summary>
        /// Create instance with null message.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void Create_NullMessage()
        {
            new RendererException(null);
        }

        /// <summary>
        /// Create instance with empty message.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentException))]
        public void Create_EmptyMessage()
        {
            new RendererException(" ");
        }

        /// <summary>
        /// Create instance with message and cause.
        /// </summary>
        [Test]
        public void Create_MessageCause()
        {
            RendererException re = new RendererException(message, cause);
            Assert.AreEqual(message, re.Message, "Message mismatches.");
            Assert.AreEqual(cause, re.InnerException, "Cause mismatches.");
        }

        /// <summary>
        /// Create instance with null message.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void Create_NullMessage2()
        {
            new RendererException(null, cause);
        }

        /// <summary>
        /// Create instance with empty message.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentException))]
        public void Create_EmptyMessage2()
        {
            new RendererException(" ", cause);
        }

        /// <summary>
        /// Create instance with null cause.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void Create_NullCause()
        {
            new RendererException(message, null);
        }

    }

}
