/**
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights Reserved.
 */
package com.topcoder.rules.dependencymap.view.failuretests;

import java.awt.Insets;
import java.io.File;

import junit.framework.TestCase;

import com.topcoder.rules.dependencymap.view.Dependency;
import com.topcoder.rules.dependencymap.view.FixedGridLayoutManager;
import com.topcoder.rules.dependencymap.view.RendererGraphics;
import com.topcoder.rules.dependencymap.view.SVGRenderer;
import com.topcoder.rules.dependencymap.view.ShapeFactory;

/**
 * Failure test cases for FixedGridLayoutManager.
 *
 * @author AdamSelene
 */
public class FGLTest extends TestCase {
    
	private Insets goodInset = new Insets(1,2,3,4);
	private Dependency goodDep = new Dependency("test");
	private SVGRenderer svgr = new SVGRenderer(new File("."));
	private RendererGraphics goodGraphics = svgr.getGraphics(goodDep, 1, 1);	
	private ShapeFactory goodSF = new ShapeFactory();
	
	public FGLTest() throws Exception {
		
	}
	
	
	
    /**
     * Invalid input to constructor.
     *
     */
	public void testCon2_Inv() {
        try {
            new FixedGridLayoutManager(-1, 0, goodInset);
            fail("Should have thrown IllegalArgumentException.");
        } catch (IllegalArgumentException npe) { /* expected */ }
    }
	
    /**
     * Invalid input to constructor.
     *
     */
	public void testCon2_Inv2() {
        try {
            new FixedGridLayoutManager(-1, -1, goodInset);
            fail("Should have thrown IllegalArgumentException.");
        } catch (IllegalArgumentException npe) { /* expected */ }
    }    
	
    /**
     * Invalid input to constructor.
     *
     */
	public void testCon2_Inv3() {
        try {
            new FixedGridLayoutManager(0, -1, goodInset);
            fail("Should have thrown IllegalArgumentException.");
        } catch (IllegalArgumentException npe) { /* expected */ }
    }  
	
	/**
     * Invalid input to constructor.
     *
     */
	public void testCon2_Inv4() {
        try {
            new FixedGridLayoutManager(0, Integer.MIN_VALUE, goodInset);
            fail("Should have thrown IllegalArgumentException.");
        } catch (IllegalArgumentException npe) { /* expected */ }
    }
	
	
	/**
     * Invalid input to constructor.
     *
     */
	public void testCon2_Null() {
        try {
            new FixedGridLayoutManager(0, 0, null);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */ }
    }
	
	/**
     * Valid input to layout.
     *
     */
	public void testLayout_Silent() throws Exception {
        new FixedGridLayoutManager().layout(goodDep, goodSF, svgr);
    }

	
	/**
     * Invalid input to layout.
     *
     */
	public void testLayout_N1() {
        try {
            new FixedGridLayoutManager().layout(null, goodSF, svgr);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { 
        	/* expected */ 
        } catch (Exception e) {
        	fail("Should have thrown NullPointerException.");
        }
        
    }

	/**
     * Invalid input to layout.
     *
     */
	public void testLayout_N2() {
        try {
            new FixedGridLayoutManager().layout(goodDep, null, svgr);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */ 
        } catch (Exception e) {
        	fail("Should have thrown NullPointerException.");
        }
    }

	/**
     * Invalid input to layout.
     *
     */
	public void testLayout_N3() {
        try {
            new FixedGridLayoutManager().layout(goodDep, goodSF, null);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */ 
        } catch (Exception e) {
        	fail("Should have thrown NullPointerException.");
        }
    }

	/**
     * Invalid input to layout.
     *
     */
	public void testLayout_N4() {
        try {
            new FixedGridLayoutManager().layout(null, null, svgr);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */ 
        } catch (Exception e) {
        	fail("Should have thrown NullPointerException.");
        }
    }

	/**
     * Invalid input to layout.
     *
     */
	public void testLayout_N5() {
        try {
            new FixedGridLayoutManager().layout(null, goodSF, null);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */ 
        } catch (Exception e) {
        	fail("Should have thrown NullPointerException.");
        }
    }

	/**
     * Invalid input to layout.
     *
     */
	public void testLayout_N6() {
        try {
            new FixedGridLayoutManager().layout(goodDep, null, null);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */ 
        } catch (Exception e) {
        	fail("Should have thrown NullPointerException.");
        }
    }

	/**
     * Invalid input to layout.
     *
     */
	public void testLayout_N7() {
        try {
            new FixedGridLayoutManager().layout(null, null, null);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */
        } catch (Exception e) {
        	fail("Should have thrown NullPointerException.");
        }
    }	
}
